@@ -688,6 +688,7 @@ xfdesktop_settings_dialog_populate_image_list(AppearancePanel *panel)
         xfconf_channel_set_string(panel->channel, prop_image, image_file);
         xfconf_channel_set_string(panel->channel, prop_last, image_file);
 
+        /* Add all backdrops in xfce4/backdrops/ for backwards compatibility with 4.8 */
         backdrop_dirs = xfce_resource_lookup_all(XFCE_RESOURCE_DATA,
                                                  "xfce4/backdrops/");
         for(i = 0; backdrop_dirs[i]; ++i) {
@@ -696,6 +697,18 @@ xfdesktop_settings_dialog_populate_image_list(AppearancePanel *panel)
             if(tmp)
                 image_file_iter = tmp;
         }
+        g_strfreev(backdrop_dirs);
+
+        /* Add all backdrops in backgrounds/xfce/ */
+        backdrop_dirs = xfce_resource_lookup_all(XFCE_RESOURCE_DATA,
+                                                 "backgrounds/xfce/");
+        for(i = 0; backdrop_dirs[i]; ++i) {
+            tmp = xfdesktop_image_list_add_dir(ls, backdrop_dirs[i],
+                                               image_file);
+            if(tmp)
+                image_file_iter = tmp;
+        }
+        g_strfreev(backdrop_dirs);
 
         if(!image_file_iter)
             image_file_iter = xfdesktop_settings_image_treeview_add(GTK_TREE_MODEL(ls), image_file);
@@ -1323,6 +1336,13 @@ xfdesktop_settings_dialog_add_screens(GtkBuilder *main_gxml,
 
     chk_show_thumbnails = GTK_WIDGET(gtk_builder_get_object(main_gxml,
                                                             "chk_show_thumbnails"));
+    /* The default value when this property is not set, is 'TRUE'.
+     * the bind operation defaults to 'FALSE' for unset boolean properties. 
+     *
+     * Make the checkbox correspond to the default behaviour.
+     */
+    gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON(chk_show_thumbnails),
+                                  TRUE);
 
     nscreens = gdk_display_get_n_screens(gdk_display_get_default());
 
